@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/glite/org.glite.jobid.api-c/src/strmd5.c,v 1.5 2010/03/12 16:52:32 zsustr Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -22,16 +22,12 @@ limitations under the License.
 #include <stdio.h>
 #include <stdlib.h>
 
-#define MD5_JOBID_PROTO static
-#include "md5.h"
-#include "strmd5.h"
-
-#include "md5_dgst.c"
+#include <openssl/md5.h>
 
 
 static char mbuf[33];
 static const char* b64 = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_";
-static char *b64r;
+#include "b64r.c"
 
 int base64_encode(const void *enc, int enc_size, char *out, int out_max_size)
 {
@@ -81,13 +77,6 @@ int base64_decode(const char *enc,char *out,int max_out_size)
 	int	shift = 0;
 	int	out_size = 0;
 
-	if (!b64r) {
-		int	i;
-		b64r = calloc(128,1);
-
-		for (i=0; b64[i]; i++) b64r[(int)b64[i]] = i;
-	}
-
 	while (*enc && *enc != '=') {
 		bits <<= 6;
 		bits |= b64r[(int)*enc++];
